# SPDX-FileCopyrightText: 2022 Gregory Clunies <greg@reflekt-ci.com>
#
# SPDX-License-Identifier: Apache-2.0

reflekt_columns = [
    "source_schema",
    "source_table",
    "tracking_plan",
    "event_text",
    "call_type",
]

reflekt_reserved_columns = [
    "user_id",
    "anonymous_id",
]
